@@ -23,8 +23,21 @@ namespace LongoMatch.Common
 
 
 	public enum ProjectType {
-		NewCaptureProject,
-		NewFileProject,
+		CaptureProject,
+		FakeCaptureProject,
+		FileProject,
 		EditProject,
+		None,
+	}
+	
+	public enum EndCaptureResponse {
+		Return = 234,
+		Quit = 235,
+		Save = 236
+	}
+	
+	public enum TagMode {
+		Predifined,
+		Free
 	}
 }
